@@ -324,6 +324,25 @@ def wait_function_status(function, status=["Ready", "Failed"]):
     return function.status
 
 
+def list_services(tags=[]):
+    """
+    List available services (i.e. CDF Functions) that match a set of tags.
+    If not tags are provided, all services are listed.
+    Input:
+        - tags: ([string]): list of tags to search for in the function
+        description
+    Output:
+        - ([string]): list of function names (i.e. external_id's )
+    """
+    client = global_client["functions"]
+    functions = client.functions.list()
+    if tags:
+        functions = [f.external_id for f in functions if 
+        any([True if tag in f.description else False for tag in tags])
+        ]
+    return functions
+
+
 def download_file(id, path):
     """
     Download file from Cognite
